**Devlog guidelines:**
- All new code needs to be tested and documented. Add daily tasks accordingly.
- The written dissertation (or at least the notes to write it) needs to move along with all the other goals.

# Daily sprint goals

- integrate the process docs into the main docs
- colab demo
- implement LR class

# Tasks for the day

- [ ] bug fixes
	- [ ] custom exception for LLDF saving issues
	- [ ] remove redundant component number in PCA
	- [ ] test cases for on/off output in PCA, LDA, SVM
- [ ] colab demo
- [ ] LR class

# Notes

- 

# Shutdown and Retrospective

- [ ] test and validate all new code
- [ ] commit to the remote repo
- [ ] make a schedule for tomorrow

**Did anything go wrong? What could have been done better, and how?**
- None of the assigned work for today was completed. At least the docs were completely overhauled.